@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,8 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
 
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 import proto  # type: ignore
 
 __protobuf__ = proto.module(
@@ -52,7 +52,7 @@ class Secret(proto.Message):
         create_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. The time at which the
             [Secret][google.cloud.secrets.v1beta1.Secret] was created.
-        labels (Sequence[google.cloud.secretmanager_v1beta1.types.Secret.LabelsEntry]):
+        labels (MutableMapping[str, str]):
             The labels assigned to this Secret.
 
             Label keys must be between 1 and 63 characters long, have a
@@ -68,21 +68,25 @@ class Secret(proto.Message):
             No more than 64 labels can be assigned to a given resource.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
-    replication = proto.Field(
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    replication: "Replication" = proto.Field(
         proto.MESSAGE,
         number=2,
         message="Replication",
     )
-
-    create_time = proto.Field(
+    create_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=3,
-        message=timestamp.Timestamp,
+        message=timestamp_pb2.Timestamp,
+    )
+    labels: MutableMapping[str, str] = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=4,
     )
-
-    labels = proto.MapField(proto.STRING, proto.STRING, number=4)
 
 
 class SecretVersion(proto.Message):
@@ -123,21 +127,21 @@ class SecretVersion(proto.Message):
         DISABLED = 2
         DESTROYED = 3
 
-    name = proto.Field(proto.STRING, number=1)
-
-    create_time = proto.Field(
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    create_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=2,
-        message=timestamp.Timestamp,
+        message=timestamp_pb2.Timestamp,
     )
-
-    destroy_time = proto.Field(
+    destroy_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=3,
-        message=timestamp.Timestamp,
+        message=timestamp_pb2.Timestamp,
     )
-
-    state = proto.Field(
+    state: State = proto.Field(
         proto.ENUM,
         number=4,
         enum=State,
@@ -147,19 +151,31 @@ class SecretVersion(proto.Message):
 class Replication(proto.Message):
     r"""A policy that defines the replication configuration of data.
 
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         automatic (google.cloud.secretmanager_v1beta1.types.Replication.Automatic):
             The [Secret][google.cloud.secrets.v1beta1.Secret] will
             automatically be replicated without any restrictions.
+
+            This field is a member of `oneof`_ ``replication``.
         user_managed (google.cloud.secretmanager_v1beta1.types.Replication.UserManaged):
             The [Secret][google.cloud.secrets.v1beta1.Secret] will only
             be replicated into the locations specified.
+
+            This field is a member of `oneof`_ ``replication``.
     """
 
     class Automatic(proto.Message):
         r"""A replication policy that replicates the
         [Secret][google.cloud.secrets.v1beta1.Secret] payload without any
         restrictions.
+
         """
 
     class UserManaged(proto.Message):
@@ -168,7 +184,7 @@ class Replication(proto.Message):
         locations specified in [Secret.replication.user_managed.replicas][]
 
         Attributes:
-            replicas (Sequence[google.cloud.secretmanager_v1beta1.types.Replication.UserManaged.Replica]):
+            replicas (MutableSequence[google.cloud.secretmanager_v1beta1.types.Replication.UserManaged.Replica]):
                 Required. The list of Replicas for this
                 [Secret][google.cloud.secrets.v1beta1.Secret].
 
@@ -185,22 +201,26 @@ class Replication(proto.Message):
                     example: ``"us-east1"``.
             """
 
-            location = proto.Field(proto.STRING, number=1)
+            location: str = proto.Field(
+                proto.STRING,
+                number=1,
+            )
 
-        replicas = proto.RepeatedField(
+        replicas: MutableSequence[
+            "Replication.UserManaged.Replica"
+        ] = proto.RepeatedField(
             proto.MESSAGE,
             number=1,
             message="Replication.UserManaged.Replica",
         )
 
-    automatic = proto.Field(
+    automatic: Automatic = proto.Field(
         proto.MESSAGE,
         number=1,
         oneof="replication",
         message=Automatic,
     )
-
-    user_managed = proto.Field(
+    user_managed: UserManaged = proto.Field(
         proto.MESSAGE,
         number=2,
         oneof="replication",
@@ -219,7 +239,10 @@ class SecretPayload(proto.Message):
             64KiB.
     """
 
-    data = proto.Field(proto.BYTES, number=1)
+    data: bytes = proto.Field(
+        proto.BYTES,
+        number=1,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
